@@ -11,7 +11,6 @@ a user to syntactically flawed scripts.
 Implementation based on <draft-martin-managesieve-12>.
 """
 
-import sys, os
 import socket
 import re
 import base64
@@ -19,8 +18,6 @@ import ssl
 
 from digest_md5 import DigestMD5
 
-from binascii import b2a_base64
-
 CRLF = '\r\n'
 
 KNOWN_CAPABILITIES = ["IMPLEMENTATION", "SASL", "SIEVE",
@@ -33,6 +30,7 @@ SUPPORTED_AUTH_MECHS = ["DIGEST-MD5", "PLAIN", "LOGIN"]
 class Error(Exception):
     pass
 
+
 class Response(Exception):
     def __init__(self, code, data):
         self.code = code
@@ -41,6 +39,7 @@ class Response(Exception):
     def __str__(self):
         return "%s %s" % (self.code, self.data)
 
+
 class Literal(Exception):
     def __init__(self, value):
         self.value = value
@@ -48,6 +47,7 @@ class Literal(Exception):
     def __str__(self):
         return "{%d}" % self.value
 
+
 def authentication_required(meth):
     """Simple class method decorator.
 
@@ -55,12 +55,15 @@ def authentication_required(meth):
 
     :param meth: the original called method
     """
+
     def check(cls, *args, **kwargs):
         if cls.authenticated:
             return meth(cls, *args, **kwargs)
         raise Error("Authentication required")
+
     return check
 
+
 class Client(object):
     read_size = 4096
     read_timeout = 5
@@ -88,7 +91,7 @@ class Client(object):
     def __dprint(self, message):
         if not self.__debug:
             return
-        print(message)
+        print "DEBUG: %s" % message
 
     def __read_block(self, size):
         """Read a block of 'size' bytes from the server.
@@ -115,9 +118,8 @@ class Client(object):
             return buf
         try:
             buf += self.sock.recv(size)
-        except (socket.timeout, ssl.SSLError) as err:
+        except (socket.timeout, ssl.SSLError), e:
             raise Error("Failed to read %d bytes from the server" % size)
-        self.__dprint("S: %s" % buf)
         return buf
 
     def __read_line(self):
@@ -131,7 +133,7 @@ class Client(object):
         Client.read_timeout seconds. If no data can be
         retrieved, it is considered as a fatal error and an 'Error'
         exception is raised.
-
+        
         :rtype: string
         :return: the read line
         """
@@ -140,7 +142,7 @@ class Client(object):
             try:
                 pos = self.__read_buffer.index(CRLF)
                 ret = self.__read_buffer[0:pos]
-                self.__read_buffer = self.__read_buffer[pos+len(CRLF):]
+                self.__read_buffer = self.__read_buffer[pos + len(CRLF):]
                 break
             except ValueError:
                 pass
@@ -164,7 +166,6 @@ class Client(object):
                 if m.group(1) == "NO":
                     self.__parse_error(m.group(2))
                 raise Response(m.group(1), m.group(2))
-        self.__dprint("S: %s" % ret)
         return ret
 
     def __read_response(self, nblines=-1):
@@ -185,11 +186,11 @@ class Client(object):
         while True:
             try:
                 line = self.__read_line()
-            except Response as inst:
+            except Response, inst:
                 code = inst.code
                 data = inst.data
                 break
-            except Literal as inst:
+            except Literal, inst:
                 resp += self.__read_block(inst.value)
                 continue
             if not len(line):
@@ -238,7 +239,7 @@ class Client(object):
         tosend = name
         if len(args):
             tosend += " " + " ".join(self.__prepare_args(args))
-        self.__dprint("C: %s" % tosend)
+        self.__dprint("Command: %s" % tosend)
         self.sock.send("%s%s" % (tosend, CRLF))
         for l in extralines:
             self.sock.send("%s%s" % (l, CRLF))
@@ -290,20 +291,15 @@ class Client(object):
             self.errcode = ""
         self.errmsg = m.group(2).strip('"')
 
-    def _plain_authentication(self, login, password, authzid=None):
+    def _plain_authentication(self, login, password):
         """SASL PLAIN authentication
-
+        
         :param login: username
         :param password: clear password
         :return: True on success, False otherwise.
         """
-        if not authzid == None:
-            params = b2a_base64("%s\0%s\0%s" % (authzid, login, password)).strip()
-        else:
-            params = base64.b64encode('\0' + '\0'.join([login, password]))
-
+        params = base64.b64encode('\0' + '\0'.join([login, password]))
         code, data = self.__send_command("AUTHENTICATE", ["PLAIN", params])
-
         if code == "OK":
             return True
         return False
@@ -389,7 +385,7 @@ class Client(object):
         """STARTTLS command
 
         See MANAGESIEVE specifications, section 2.2.
-
+        
         :param keyfile: an eventual private key to use
         :param certfile: an eventual certificate to use
         :rtype: boolean
@@ -401,8 +397,8 @@ class Client(object):
             return False
         try:
             nsock = ssl.wrap_socket(self.sock, keyfile, certfile)
-        except ssl.SSLError as err:
-            raise Error("SSL error: %s" % str(err))
+        except ssl.SSLError, e:
+            raise Error("SSL error: %s" % str(e))
         self.sock = nsock
         self.__capabilities = {}
         self.__get_capabilities()
@@ -443,14 +439,14 @@ class Client(object):
 
         They're read from server capabilities. (see the CAPABILITY
         command)
-
+        
         :rtype: string
         """
         if type(self.__capabilities["SIEVE"]) == str:
             self.__capabilities["SIEVE"] = self.__capabilities["SIEVE"].split()
         return self.__capabilities["SIEVE"]
 
-    def connect(self, login=None, password=None, starttls=False, authmech=None):
+    def connect(self, login, password, starttls=False, authmech=None):
         """Establish a connection with the server.
 
         This function must be used. It read the server capabilities
@@ -466,22 +462,16 @@ class Client(object):
             self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
             self.sock.connect((self.srvaddr, self.srvport))
             self.sock.settimeout(Client.read_timeout)
-        except socket.error as msg:
+        except socket.error, msg:
             raise Error("Connection to server failed: %s" % str(msg))
 
         if not self.__get_capabilities():
             raise Error("Failed to read capabilities from server")
-
         if starttls and not self.__starttls():
             return False
-
-        if not login == None and not password == None:
-            if self.__authenticate(login, password, authmech):
-                return True
-            else:
-                return False
-        else:
+        if self.__authenticate(login, password, authmech):
             return True
+        return False
 
     def logout(self):
         """Disconnect from the server
@@ -507,7 +497,7 @@ class Client(object):
     @authentication_required
     def havespace(self, scriptname, scriptsize):
         """Ask for available space.
-
+        
         See MANAGESIEVE specifications, section 2.5
 
         :param scriptname: script's name
@@ -580,8 +570,6 @@ class Client(object):
         content = "{%d+}%s%s" % (len(content), CRLF, content)
         code, data = \
             self.__send_command("PUTSCRIPT", [name, content])
-
-
         if code == "OK":
             return True
         return False
@@ -620,7 +608,7 @@ class Client(object):
             return False
 
         (active_script, scripts) = self.listscripts()
-        if scripts == None or not oldname in scripts:
+        if scripts is None or not oldname in scripts:
             self.errmsg = "Old script does not exist"
             return False
         if newname in scripts:
